<?php
/**
 * Promo Box section
 *
 * This is the template for the content of promo_box section
 *
 * @package Theme Palace
 * @subpackage Mega Blog Pro
 * @since Mega Blog Pro 1.0.0
 */
if ( ! function_exists( 'mega_blog_pro_add_promo_box_section' ) ) :
    /**
    * Add promo_box section
    *
    *@since Mega Blog Pro 1.0.0
    */
    function mega_blog_pro_add_promo_box_section() {
    	$options = mega_blog_pro_get_theme_options();
        // Check if promo_box is enabled on frontpage
        $promo_box_enable = apply_filters( 'mega_blog_pro_section_status', true, 'promo_box_section_enable' );

        if ( true !== $promo_box_enable ) {
            return false;
        }
        // Get promo_box section details
        $section_details = array();
        $section_details = apply_filters( 'mega_blog_pro_filter_promo_box_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render promo_box section now.
        mega_blog_pro_render_promo_box_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_blog_pro_get_promo_box_section_details' ) ) :
    /**
    * promo_box section details.
    *
    * @since Mega Blog Pro 1.0.0
    * @param array $input promo_box section details.
    */
    function mega_blog_pro_get_promo_box_section_details( $input ) {
        $options = mega_blog_pro_get_theme_options();

        // Content type.
        $promo_box_content_type  = $options['promo_box_content_type'];
        $promo_box_count = ! empty( $options['promo_box_count'] ) ? $options['promo_box_count'] : 3;
        $content = array();
        switch ( $promo_box_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <=  $promo_box_count; $i++ ) {
                    if ( ! empty( $options['promo_box_content_page_' . $i] ) )
                        $page_ids[] = $options['promo_box_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $promo_box_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <=  $promo_box_count; $i++ ) {
                    if ( ! empty( $options['promo_box_content_post_' . $i] ) )
                        $post_ids[] = $options['promo_box_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $promo_box_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['promo_box_content_category'] ) ? $options['promo_box_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $promo_box_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;


            case 'recent':
                $cat_ids = ! empty( $options['promo_box_exclude_category'] ) ? ( array ) $options['promo_box_exclude_category'] : array();
                
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $promo_box_count ),
                    'ignore_sticky_posts'   => true,
                    'category__not_in'      => ( array ) $cat_ids,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// promo_box section content details.
add_filter( 'mega_blog_pro_filter_promo_box_section_details', 'mega_blog_pro_get_promo_box_section_details' );


if ( ! function_exists( 'mega_blog_pro_render_promo_box_section' ) ) :
  /**
   * Start promo_box section
   *
   * @return string promo_box content
   * @since Mega Blog Pro 1.0.0
   *
   */
   function mega_blog_pro_render_promo_box_section( $content_details = array() ) {
        $options = mega_blog_pro_get_theme_options();
        $column = ! empty( $options['promo_box_column'] ) ? $options['promo_box_column'] : 'col-3';

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="promo-box-posts" class="page-section relative">
                <div class="wrapper">
                    <div class="section-content <?php echo esc_attr( $column ); ?>">
                        <?php foreach ( $content_details as $content ) :
                            ?>
                            <article class="hentry">
                                <div class="post-wrapper">
                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>
                                    </div><!-- .entry-container -->

                                    <div class="promo_box-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');"></div><!-- .promo_box-image -->
                                </div><!-- .post-wrapper -->
                            </article>
                        <?php endforeach; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #promo_box-posts -->
    <?php }
endif;